const jwt = require("jsonwebtoken");
const fs = require("fs");
let token;

var claims = {},
    dir = __dirname + '/claims/';
fs.readdirSync(dir).forEach(function (file) {
    claims[file.replace(/\.json$/, '')] = require(dir + file);
});

//Input respective keypaths here
const publicKey = fs.readFileSync("./keys/public_key_ec.pem");
const privateKey = fs.readFileSync("./keys/private_key_ec.pem");
//Input key signing algorithm here
const keyAlgorithm = "ES256";
//Input desired JSON filename for claims here
const usedClaims = "IdToken";
//Input desired expiry in seconds from current time here.
const desiredExpiry = (86400);


//Spread the claims and add logic to pull the current date for the IAT and EXP fields
const nowInSeconds = Math.floor(Date.now() / 1000); // Convert milliseconds to seconds

claims[usedClaims] = {
  ...claims[usedClaims],
  iat: nowInSeconds,
  nbf: nowInSeconds,
  exp: nowInSeconds + desiredExpiry,
};

//Generate the token using the claims, private key, and algorith
try {
  token = jwt.sign(claims[usedClaims], privateKey, { algorithm: keyAlgorithm });
} catch (err) {
  console.log(
    "\n\n\n" +
      "Erorr signing the token, this is likely due to a mismatch between the algorithm attempting to be used to sign the token, and the type used by the key. - Error below" +
      "\n\n\n"
  );
  console.error(err);
  process.exit();
}

//output signed token
console.log("\n\n\n Signed Token - \n" + token);

jwt.verify(token, publicKey, { algorithms: keyAlgorithm }, (err, decoded) => {
  if (err) {
    console.log(
      "\n\n\n" +
        "Erorr verifying the token, this is likely due to a pub/private key mismatch - Error below" +
        "\n\n\n"
    );
    console.error(err);
    // Handle the verification error
  } else {
    console.log("\n\n\n Successfully verified token signature, decoded token - ");
    console.log(decoded);
    // Handle the verified JWT
  }
});
